import requests
from typing import List
from zcc_utils import time_utils


if __name__ == "__main__":
    # time_local = time.localtime(1620557507)
    # print(type(time_local))
    # print(time_local)
    print(time_utils.float_hour_to_time(12.99))


def get_after_point_number_to_str(number: float):
    """
    获取小数点后的数，1.2 => 2
    :param number: 数字 float
    :return: 小数点后的数字 string
    """
    s1_list = str(number).split('.')
    return s1_list[1]


def get_after_point_number_to_float(number: float):
    """
    获取小数点后的数，1.2=>0.2
    :param number: 数字 float
    :return: 小数点后的数字 float
    """
    s1_list = str(number).split('.')
    return float('0.{0}'.format(s1_list[1]))


if __name__ == "__main__":
    print(get_after_point_number_to_float(1.2))



import time
import datetime
import zcc_utils.math_utils as math_utils


def second_to_minute(second: int):
    """
    秒转分钟
    :param second: 秒 int
    :return: 分钟 float
    """
    return second / 60


def second_to_hour(second: int):
    """
    秒转小时
    :param second: 秒 int
    :return: 小时 float
    """
    return second / 60 / 60


def float_hour_to_time(hour: float):
    """
    float类型的小时转time类型，12.99小时=>12:59:24
    :param hour:
    :return:
    """
    minute = math_utils.get_after_point_number_to_float(hour) * 60
    second = math_utils.get_after_point_number_to_float(minute) * 60
    return datetime.time(hour=int(hour), minute=int(minute), second=int(second))


if __name__ == "__main__":
    # time_local = time.localtime(1620557507)
    # print(type(time_local))
    # print(time_local)
    print(float_hour_to_time(12.99))



import json
from typing import List
import importlib


class Dict(dict):
    __setattr__ = dict.__setitem__
    __getattr__ = dict.__getitem__


def dict_to_object(dictObj):
    """
    字典转对象
    :param dictObj: dic对象
    :return: obj
    """
    # 支持嵌套类型
    if isinstance(dictObj, list):
        insts = []
        for i in dictObj:
            insts.append(dict_to_object(i))
        return insts

    if not isinstance(dictObj, dict):
        return dictObj
    inst = Dict()
    for k, v in dictObj.items():
        inst[k] = dict_to_object(v)
    return inst


def json_to_object(json_str: str):
    """
    json字符串转对象
    :param json_str: json字符串
    :return: obj
    """
    return dict_to_object(json.loads(json_str))

if __name__=="__main__":
    print(type(importlib.import_module("zcc_utils.json_tools")))
